package com.link.core.util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.link.base.logs.model.HttpLog;
import com.link.core.cllog.LCLogger;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLDecoder;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import javax.servlet.ServletInputStream;
import javax.servlet.http.HttpServletRequest;
import org.apache.http.Consts;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.NameValuePair;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.util.CollectionUtils;

public class HttpRequestUtil {
   public static final String HTTP_POST = "POST";
   public static final String HTTP_GET = "GET";
   public static final String HTTP_PUT = "PUT";
   private static final Logger logger = LogManager.getLogger(HttpRequestUtil.class);

   public static String sendGet(String url, String param) {
      String result = "";
      BufferedReader in = null;
      HttpLog httpLog = new HttpLog();

      try {
         httpLog.setUrl(url);
         httpLog.setReqParams(param);
         httpLog.setReqTime(System.currentTimeMillis());
         String urlNameString = url;
         if (param != null && !"".equals(param)) {
            urlNameString = urlNameString + "?" + param;
         }

         LCLogger.info().withMessageKey("HttpRequestUtil.sendGet").withMessage("HttpRequestUtil.sendGet===>" + urlNameString).flush();
         URL realUrl = new URL(urlNameString);
         HttpURLConnection connection = (HttpURLConnection)realUrl.openConnection();
         connection.setRequestProperty("accept", "*/*");
         connection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded; charset=UTF-8");
         connection.setRequestProperty("Accept-Language", "zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3");
         connection.setRequestProperty("connection", "Keep-Alive");
         connection.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
         connection.setConnectTimeout(30000);
         connection.setReadTimeout(60000);
         connection.connect();
         Map<String, List<String>> map = connection.getHeaderFields();

         String line;
         for(in = new BufferedReader(new InputStreamReader(connection.getInputStream(), "UTF-8")); (line = in.readLine()) != null; result = result + line) {
         }

         httpLog.setHttpStatus(connection.getResponseCode());
         httpLog.setRespTime(System.currentTimeMillis());
         httpLog.setRespBody(result);
      } catch (Exception var22) {
         Exception e = var22;
         httpLog.setErrorMsg(e.getMessage());
         logger.error("HttpRequestUtil捕获异常: ", e);
      } finally {
         Exception e3;
         try {
            if (in != null) {
               in.close();
            }
         } catch (Exception var21) {
            e3 = var21;
            logger.error("HttpRequestUtil捕获异常: ", e3);
         }

         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var20) {
            e3 = var20;
            LCLogger.withException(e3);
         }

      }

      return result;
   }

   public static String sendPost(String url, String content, String contentType) {
      HttpLog httpLog = new HttpLog();
      httpLog.setUrl(url);
      httpLog.setReqParams(content);
      httpLog.setReqTime(System.currentTimeMillis());
      OutputStreamWriter out = null;
      BufferedReader in = null;
      String result = "";
      System.err.println("HttpRequestUtil.sendPost===>" + url);

      try {
         URL realUrl = new URL(url);
         HttpURLConnection conn = null;
         conn = (HttpURLConnection)realUrl.openConnection();
         conn.setDoOutput(true);
         conn.setDoInput(true);
         conn.setRequestMethod("POST");
         if (contentType != null && !"".equals(contentType)) {
            conn.setRequestProperty("Content-Type", contentType);
         } else {
            conn.setRequestProperty("Content-Type", "text/html;charset=UTF-8");
         }

         conn.setConnectTimeout(30000);
         conn.setReadTimeout(30000);
         conn.connect();
         out = new OutputStreamWriter(conn.getOutputStream(), "UTF-8");
         out.write(content);
         out.flush();

         String line;
         for(in = new BufferedReader(new InputStreamReader(conn.getInputStream())); (line = in.readLine()) != null; result = result + line) {
         }

         httpLog.setHttpStatus(conn.getResponseCode());
         httpLog.setRespTime(System.currentTimeMillis());
         httpLog.setRespBody(result);
      } catch (Exception var22) {
         Exception e = var22;
         httpLog.setErrorMsg(e.getMessage());
         logger.error("HttpRequestUtil捕获异常: ", e);
      } finally {
         try {
            if (out != null) {
               out.close();
            }

            if (in != null) {
               in.close();
            }
         } catch (IOException var21) {
            IOException ex = var21;
            logger.error("HttpRequestUtil捕获异常: ", ex);
         }

         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var20) {
            Exception e3 = var20;
            LCLogger.withException(e3);
         }

      }

      return result;
   }

   public static String sendPostWithAuth(String url, String content, String contentType, String auth) {
      HttpLog httpLog = new HttpLog();
      httpLog.setUrl(url);
      httpLog.setReqParams(content);
      httpLog.setReqTime(System.currentTimeMillis());
      OutputStreamWriter out = null;
      BufferedReader in = null;
      String result = "";
      System.err.println("HttpRequestUtil.sendPost===>" + url);

      try {
         URL realUrl = new URL(url);
         HttpURLConnection conn = null;
         conn = (HttpURLConnection)realUrl.openConnection();
         conn.setDoOutput(true);
         conn.setDoInput(true);
         conn.setRequestMethod("POST");
         if (contentType != null && !"".equals(contentType)) {
            conn.setRequestProperty("Content-Type", contentType);
         } else {
            conn.setRequestProperty("Content-Type", "text/html;charset=UTF-8");
         }

         if (StringUtils.isNotBlank(auth)) {
            conn.setRequestProperty("Authorization", auth);
         }

         conn.setConnectTimeout(30000);
         conn.setReadTimeout(30000);
         conn.connect();
         out = new OutputStreamWriter(conn.getOutputStream(), "UTF-8");
         out.write(content);
         out.flush();

         String line;
         for(in = new BufferedReader(new InputStreamReader(conn.getInputStream())); (line = in.readLine()) != null; result = result + line) {
         }

         httpLog.setHttpStatus(conn.getResponseCode());
         httpLog.setRespTime(System.currentTimeMillis());
         httpLog.setRespBody(result);
      } catch (Exception var23) {
         Exception e = var23;
         httpLog.setErrorMsg(e.getMessage());
         logger.error("HttpRequestUtil捕获异常: ", e);
      } finally {
         try {
            if (out != null) {
               out.close();
            }

            if (in != null) {
               in.close();
            }
         } catch (IOException var22) {
            IOException ex = var22;
            logger.error("HttpRequestUtil捕获异常: ", ex);
         }

         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var21) {
            Exception e3 = var21;
            LCLogger.withException(e3);
         }

      }

      return result;
   }

   public static String jsonPost(String strURL, String params) {
      try {
         return jsonRequest(strURL, params, "POST");
      } catch (Exception var3) {
         Exception e = var3;
         logger.error("HttpRequestUtil捕获异常: ", e);
         return "error";
      }
   }

   public static String jsonRequest(String strURL, String params, String requestMethod) {
      return jsonRequest(strURL, params, requestMethod, (Integer)null);
   }

   public static String jsonRequest(String strURL, String params, String requestMethod, Integer outTime) {
      HttpLog httpLog = new HttpLog();
      httpLog.setUrl(strURL);
      httpLog.setReqParams(params);
      httpLog.setReqTime(System.currentTimeMillis());
      OutputStreamWriter out = null;
      BufferedReader in = null;
      String result = "";
      if (null == outTime) {
         outTime = 30000;
      }

      try {
         URL url = new URL(strURL);
         HttpURLConnection connection = (HttpURLConnection)url.openConnection();
         connection.setDoOutput(true);
         connection.setDoInput(true);
         connection.setUseCaches(false);
         connection.setInstanceFollowRedirects(true);
         connection.setRequestMethod(requestMethod);
         connection.setRequestProperty("Accept", "application/json");
         connection.setRequestProperty("Content-Type", "application/json");
         connection.setConnectTimeout(outTime);
         connection.setReadTimeout(outTime);
         connection.connect();
         out = new OutputStreamWriter(connection.getOutputStream(), "UTF-8");
         out.append(params);
         out.flush();

         String line;
         for(in = new BufferedReader(new InputStreamReader(connection.getInputStream())); (line = in.readLine()) != null; result = result + line) {
         }

         httpLog.setRespBody(result);
         httpLog.setHttpStatus(connection.getResponseCode());
         httpLog.setRespTime(System.currentTimeMillis());
         String var11 = result;
         return var11;
      } catch (IOException var25) {
         IOException e = var25;
         httpLog.setErrorMsg(e.getMessage());
         logger.error("HttpRequestUtil捕获异常: ", e);
      } finally {
         try {
            if (out != null) {
               out.close();
            }

            if (in != null) {
               in.close();
            }
         } catch (IOException var24) {
            IOException ex = var24;
            logger.error("HttpRequestUtil捕获异常: ", ex);
         }

         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var23) {
            Exception e3 = var23;
            LCLogger.withException(e3);
         }

      }

      return "error";
   }

   public static String sendPostByByte(String url, String content, String contentType, String savePath) {
      HttpLog httpLog = new HttpLog();
      httpLog.setUrl(url);
      httpLog.setReqParams(content);
      httpLog.setReqTime(System.currentTimeMillis());
      BufferedOutputStream bos = null;
      String filePath = null;
      String result = "";
      System.err.println("HttpRequestUtil.sendPost===>" + url);

      try {
         URL realUrl = new URL(url);
         HttpURLConnection conn = null;
         conn = (HttpURLConnection)realUrl.openConnection();
         conn.setDoOutput(true);
         conn.setDoInput(true);
         conn.setRequestMethod("POST");
         if (contentType != null && !"".equals(contentType)) {
            conn.setRequestProperty("Content-Type", contentType);
         } else {
            conn.setRequestProperty("Content-Type", "text/html;charset=UTF-8");
         }

         conn.setConnectTimeout(30000);
         conn.setReadTimeout(30000);
         conn.connect();
         bos = new BufferedOutputStream(conn.getOutputStream());
         byte[] b = content.getBytes();
         bos.write(b);
         bos.flush();
         if (!savePath.endsWith("/")) {
            savePath = savePath + "/";
         }

         System.err.println(conn.getHeaderField("Content-Type"));
         String fileExt = getFileEndWitsh(conn.getHeaderField("Content-Type"));
         filePath = savePath + "ceshi" + fileExt;
         BufferedInputStream bis = new BufferedInputStream(conn.getInputStream());
         Throwable var13 = null;

         try {
            FileOutputStream fos = new FileOutputStream(new File(filePath));
            Throwable var15 = null;

            try {
               byte[] buf = new byte[8096];
               int size = false;

               int size;
               while((size = bis.read(buf)) != -1) {
                  fos.write(buf, 0, size);
               }
            } catch (Throwable var67) {
               var15 = var67;
               throw var67;
            } finally {
               if (fos != null) {
                  if (var15 != null) {
                     try {
                        fos.close();
                     } catch (Throwable var66) {
                        var15.addSuppressed(var66);
                     }
                  } else {
                     fos.close();
                  }
               }

            }
         } catch (Throwable var69) {
            var13 = var69;
            throw var69;
         } finally {
            if (bis != null) {
               if (var13 != null) {
                  try {
                     bis.close();
                  } catch (Throwable var65) {
                     var13.addSuppressed(var65);
                  }
               } else {
                  bis.close();
               }
            }

         }

         httpLog.setHttpStatus(conn.getResponseCode());
         httpLog.setRespTime(System.currentTimeMillis());
         conn.disconnect();
      } catch (Exception var71) {
         Exception e = var71;
         httpLog.setErrorMsg(e.getMessage());
         logger.error("HttpRequestUtil捕获异常: ", e);
      } finally {
         try {
            if (bos != null) {
               bos.close();
            }
         } catch (IOException var64) {
            IOException ex = var64;
            logger.error("HttpRequestUtil捕获异常: ", ex);
         }

         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var63) {
            Exception e3 = var63;
            LCLogger.withException(e3);
         }

      }

      return result;
   }

   public static String getFileEndWitsh(String contentType) {
      String fileEndWitsh = "";
      if ("image/jpeg".equals(contentType)) {
         fileEndWitsh = ".jpg";
      } else if ("audio/mpeg".equals(contentType)) {
         fileEndWitsh = ".mp3";
      } else if ("audio/amr".equals(contentType)) {
         fileEndWitsh = ".amr";
      } else if ("video/mp4".equals(contentType)) {
         fileEndWitsh = ".mp4";
      } else if ("video/mpeg4".equals(contentType)) {
         fileEndWitsh = ".mp4";
      }

      return fileEndWitsh;
   }

   public static Map<String, Object> httpPost(String url, JSONObject jsonParam, boolean noNeedResponse, String auth) {
      HttpLog httpLog = new HttpLog();
      httpLog.setUrl(url);
      httpLog.setReqParams(jsonParam.toJSONString());
      httpLog.setAuth(auth);
      HttpResponse result = null;
      CloseableHttpClient httpClient = HttpClients.createDefault();
      RequestConfig requestConfig = RequestConfig.custom().setConnectTimeout(50000).setConnectionRequestTimeout(10000).setSocketTimeout(50000).build();
      Map<String, Object> mapRet = new HashMap();
      String resultStr = "";
      HttpPost method = new HttpPost(url);
      method.setConfig(requestConfig);
      HttpEntity entity = null;

      Exception e;
      try {
         if (jsonParam != null) {
            entity = new UrlEncodedFormEntity(createParam(jsonParam), Consts.UTF_8);
         }

         method.setEntity(entity);
         if (auth != null) {
            method.setHeader("Authorization", auth);
         }

         method.addHeader("Content-Type", "application/json");
         method.addHeader("Accept", "application/json");
         httpLog.setReqTime(System.currentTimeMillis());
         result = httpClient.execute(method);
         httpLog.setRespTime(System.currentTimeMillis());
         url = URLDecoder.decode(url, "UTF-8");
         int statusCode = result.getStatusLine().getStatusCode();
         System.out.println(statusCode + "###");
         httpLog.setHttpStatus(statusCode);

         try {
            resultStr = EntityUtils.toString(result.getEntity());
            httpLog.setRespBody(resultStr);
            if (!noNeedResponse) {
               mapRet.put("success", true);
               mapRet.put("code", statusCode);
               mapRet.put("message", resultStr);
               return mapRet;
            }

            e = null;
         } catch (Exception var25) {
            e = var25;
            mapRet.put("success", false);
            mapRet.put("code", statusCode);
            mapRet.put("message", e.getMessage());
            httpLog.setErrorMsg(e.getMessage());
            return mapRet;
         }
      } catch (IOException var26) {
         IOException e = var26;
         httpLog.setErrorMsg(e.getMessage());
         mapRet.put("success", false);
         mapRet.put("message", e.getMessage());
         return mapRet;
      } finally {
         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var24) {
            Exception e3 = var24;
            LCLogger.withException(e3);
         }

      }

      return e;
   }

   private static List<NameValuePair> createParam(JSONObject param) {
      List<NameValuePair> nvps = new ArrayList();
      if (param != null) {
         Iterator var2 = param.keySet().iterator();

         while(var2.hasNext()) {
            String k = (String)var2.next();
            nvps.add(new BasicNameValuePair(k, param.get(k).toString()));
         }
      }

      return nvps;
   }

   public static String httpGet(String url, String auth) {
      HttpLog httpLog = new HttpLog();
      httpLog.setUrl(url);
      httpLog.setAuth(auth);
      String resultStr = "";

      try {
         CloseableHttpClient client = HttpClients.createDefault();
         HttpGet request = new HttpGet(url);
         if (!StringUtils.isBlank(auth)) {
            request.setHeader("Authorization", auth);
         }

         httpLog.setReqTime(System.currentTimeMillis());
         HttpResponse response = client.execute(request);
         httpLog.setRespTime(System.currentTimeMillis());
         int statusCode = response.getStatusLine().getStatusCode();
         httpLog.setRespBody(statusCode + "");
         if (statusCode == 200) {
            resultStr = EntityUtils.toString(response.getEntity());
            httpLog.setRespBody(resultStr);
            url = URLDecoder.decode(url, "UTF-8");
         }
      } catch (IOException var16) {
         IOException e = var16;
         httpLog.setErrorMsg(e.getMessage());
      } finally {
         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var15) {
            Exception e3 = var15;
            LCLogger.withException(e3);
         }

      }

      return resultStr;
   }

   public static String getJsonHttpRequestParam(HttpServletRequest request) {
      String result = "";

      try {
         ServletInputStream inStream = request.getInputStream();
         int size = request.getContentLength();
         byte[] buffer = new byte[size];
         byte[] inputByte = new byte[size];
         int count = 0;

         int rbyte;
         for(int rbyte = false; count < size; count += rbyte) {
            rbyte = inStream.read(buffer);

            for(int i = 0; i < rbyte; ++i) {
               inputByte[count + i] = buffer[i];
            }
         }

         result = new String(inputByte, 0, inputByte.length);
      } catch (IOException var9) {
         IOException e = var9;
         result = "解析请求内容解析异常；";
         logger.error("HttpRequestUtil捕获异常: ", e);
      }

      return result;
   }

   public static String sendGetThrowsException(String url, String param) throws Exception {
      String startTime = DateUtil.dateToStr(new Date(), "yyyyMMddHHmmssSSS");
      HttpLog httpLog = new HttpLog();
      httpLog.setUrl(url);
      httpLog.setReqParams(param);
      httpLog.setReqTime(System.currentTimeMillis());
      String result = "";
      BufferedReader in = null;

      try {
         String urlNameString = url;
         if (param != null && !"".equals(param)) {
            urlNameString = urlNameString + "?" + param;
         }

         URL realUrl = new URL(urlNameString);
         HttpURLConnection connection = (HttpURLConnection)realUrl.openConnection();
         connection.setRequestProperty("accept", "*/*");
         connection.setRequestProperty("connection", "Keep-Alive");
         connection.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
         connection.connect();

         String line;
         for(in = new BufferedReader(new InputStreamReader(connection.getInputStream(), "UTF-8")); (line = in.readLine()) != null; result = result + line) {
         }

         httpLog.setRespTime(System.currentTimeMillis());
         httpLog.setHttpStatus(connection.getResponseCode());
         httpLog.setRespBody(result);
         return result;
      } catch (Exception var20) {
         Exception e = var20;
         httpLog.setErrorMsg(e.getMessage());
         LCLogger.withException("发送GET请求出现异常！" + e + "(" + startTime + "-" + DateUtil.dateToStr(new Date(), "yyyyMMddHHmmssSSS") + ")");
         logger.error("HttpRequestUtil捕获异常: ", e);
         throw new Exception(e.getMessage() + "(" + startTime + "-" + DateUtil.dateToStr(new Date(), "yyyyMMddHHmmssSSS") + ")");
      } finally {
         Exception e3;
         try {
            if (in != null) {
               in.close();
            }
         } catch (Exception var19) {
            e3 = var19;
            logger.error("HttpRequestUtil捕获异常: ", e3);
         }

         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var18) {
            e3 = var18;
            LCLogger.withException(e3);
         }

      }
   }

   public static String jsonPostThrowException(String strURL, String params, String authorization) throws Exception {
      String startTime = DateUtil.dateToStr(new Date(), "yyyyMMddHHmmssSSS");
      HttpLog httpLog = new HttpLog();
      httpLog.setUrl(strURL);
      httpLog.setReqParams(params);
      httpLog.setAuth(authorization);
      httpLog.setReqTime(System.currentTimeMillis());
      OutputStreamWriter out = null;

      try {
         URL url = new URL(strURL);
         HttpURLConnection connection = (HttpURLConnection)url.openConnection();
         connection.setDoOutput(true);
         connection.setDoInput(true);
         connection.setUseCaches(false);
         connection.setInstanceFollowRedirects(true);
         connection.setRequestMethod("POST");
         connection.setRequestProperty("Accept", "application/json");
         connection.setRequestProperty("Content-Type", "application/json");
         if (!StringUtils.isBlank(authorization)) {
            connection.setRequestProperty("Authorization", authorization);
         }

         connection.connect();
         out = new OutputStreamWriter(connection.getOutputStream(), "UTF-8");
         out.append(params);
         out.flush();
         int length = connection.getContentLength();
         InputStream is = connection.getInputStream();
         if (length == -1) {
            httpLog.setRespTime(System.currentTimeMillis());
            httpLog.setHttpStatus(connection.getResponseCode());
            return "error";
         } else {
            byte[] data = new byte[length];
            byte[] temp = new byte[512];
            int readLen = false;

            int readLen;
            for(int destPos = 0; (readLen = is.read(temp)) > 0; destPos += readLen) {
               System.arraycopy(temp, 0, data, destPos, readLen);
            }

            String result = new String(data, "UTF-8");
            httpLog.setRespTime(System.currentTimeMillis());
            httpLog.setHttpStatus(connection.getResponseCode());
            httpLog.setRespBody(result);
            String var15 = result;
            return var15;
         }
      } catch (Exception var29) {
         Exception e = var29;
         httpLog.setErrorMsg(e.getMessage());
         logger.error("HttpRequestUtil捕获异常: ", e);
         throw new Exception(e.getMessage() + "(" + startTime + "-" + DateUtil.dateToStr(new Date(), "yyyyMMddHHmmssSSS") + ")");
      } finally {
         Exception e3;
         try {
            if (out != null) {
               out.close();
            }
         } catch (Exception var28) {
            e3 = var28;
            LCLogger.withException(e3);
         }

         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var27) {
            e3 = var27;
            LCLogger.withException(e3);
         }

      }
   }

   public static Map<String, Object> dmpHttpPost(String url, JSON jsonParam, Map<String, String> headerMap) {
      if (CollectionUtils.isEmpty(headerMap)) {
         throw new IllegalArgumentException("headerMap不能为空");
      } else {
         HttpLog httpLog = new HttpLog();
         httpLog.setUrl(url);
         String reqParams = jsonParam.toJSONString();
         httpLog.setReqParams(reqParams);
         httpLog.setReqTime(System.currentTimeMillis());
         HttpResponse result = null;
         CloseableHttpClient httpClient = HttpClients.createDefault();
         Map<String, Object> mapRet = new HashMap();
         String resultStr = "";
         HttpPost method = new HttpPost(url);
         HttpEntity entity = null;

         try {
            if (jsonParam != null) {
               entity = new StringEntity(reqParams, Consts.UTF_8);
            }

            method.setEntity(entity);
            Set<String> keySet = headerMap.keySet();
            Iterator var12 = keySet.iterator();

            while(var12.hasNext()) {
               String key = (String)var12.next();
               method.setHeader(key, (String)headerMap.get(key));
            }

            result = httpClient.execute(method);
            url = URLDecoder.decode(url, "UTF-8");
            httpLog.setRespTime(System.currentTimeMillis());
            int statusCode = result.getStatusLine().getStatusCode();
            httpLog.setHttpStatus(statusCode);

            try {
               resultStr = EntityUtils.toString(result.getEntity());
               httpLog.setRespBody(resultStr);
               mapRet.put("success", true);
               mapRet.put("code", statusCode);
               mapRet.put("message", resultStr);
            } catch (Exception var23) {
               Exception e = var23;
               httpLog.setErrorMsg(e.getMessage());
               mapRet.put("success", false);
               mapRet.put("code", statusCode);
               mapRet.put("message", e.getMessage());
            }
         } catch (IOException var24) {
            IOException e = var24;
            httpLog.setErrorMsg(e.getMessage());
            mapRet.put("success", false);
            mapRet.put("message", e.getMessage());
         } finally {
            try {
               LCLogger.sendHttpLog(httpLog);
            } catch (Exception var22) {
               Exception e3 = var22;
               LCLogger.withException(e3);
            }

         }

         return mapRet;
      }
   }
}
